@@ -3,14 +3,12 @@ Filter out a url piped in
 '''
 import sys
 import json
-import subprocess
 from typing import Set
 
 
 if __name__ == "__main__":
 
     import argparse
-    import sys
 
     parser = argparse.ArgumentParser()
     parser.add_argument('-e',
