@@ -1,18 +1,16 @@
-from dataclasses import make_dataclass
-from typing import List
 import json
+from dataclasses import make_dataclass
+from typing import Any, List, Tuple
+
 import yaml  # type: ignore # mypy can't find library
-from typing import Tuple
-from typing import Any
 
 from naveen.experiment.config.config_validator import ConfigValidator
 
 
 class DynamicExperimentConfigMaker(object):
-
     def make_config_from_yaml(self, config_file: str) -> dict:
         assert config_file.endswith(".yaml") or config_file.endswith(".yml")
-        with open(config_file, 'r') as yaml_input:
+        with open(config_file, "r") as yaml_input:
             yaml_config_as_dict: dict = yaml.safe_load(yaml_input)
             yaml_config_as_dict["filename"] = config_file
         return self._make_config_object(yaml_config_as_dict)  # type: ignore
@@ -40,7 +38,7 @@ class DynamicExperimentConfigMaker(object):
             if k not in ["name", "reshaper", "plotter"]:
                 fields.append((k, type(v)))
 
-        X = make_dataclass('DynamicConfig', fields)
+        X = make_dataclass("DynamicConfig", fields)
 
         # https://www.reddit.com/r/learnpython/comments/9h74no/convert_dict_to_dataclass/
         return X(**config)
