@@ -1,11 +1,10 @@
 import importlib
-from abc import ABC
 from naveen.experiment.experiment_finisher import ExperimentFinisher
 from naveen.experiment.experiment_writer import ExperimentWriter
 from naveen.experiment.config.abstract_config import AbstractConfig  # type: ignore  # noqa: E501
 
 
-class ExperimentRunner(ABC):
+class ExperimentRunner(object):
 
     def __init__(self, config: AbstractConfig,
                  package_name: str = None,  # e.g. src or experiment; name of base package # noqa: E501
