@@ -30,7 +30,7 @@ class TestMethods(unittest.TestCase):
     def setUp(self) -> None:
         self.demo = 1
         maker = DynamicExperimentConfigMaker()
-        self.config = maker.from_json("config/demo.json")
+        self.config = maker.make_config_from_json("config/demo.json")
         for fn in glob.glob('test/fixtures/1659230924/*reshaped*'):
             os.remove(fn)
         for fn in glob.glob("test/fixtures/output/*"):
@@ -86,7 +86,7 @@ class TestMethods(unittest.TestCase):
 
     def test_dynamic_config_maker_json(self) -> None:
         maker = DynamicExperimentConfigMaker()
-        config = maker.from_json("test/fixtures/config/voss.json")
+        config = maker.make_config_from_json("test/fixtures/config/voss.json")
         with open("test/fixtures/config/voss.json", "r") as inf:
             configdict = json.load(inf)
             names = [o.name for o in fields(config)]
@@ -95,7 +95,7 @@ class TestMethods(unittest.TestCase):
 
     def test_dynamic_config_maker_yaml(self) -> None:
         maker = DynamicExperimentConfigMaker()
-        config = maker.from_yaml("test/fixtures/config/voss.yaml")
+        config = maker.make_config_from_yaml("test/fixtures/config/voss.yaml")
         with open("test/fixtures/config/voss.json", "r") as inf:
             # voss.yaml and voss.json are identical
             configdict = json.load(inf)
